==> huaweicloudsdkswr-3.0.45-py2.py3-none-any.whl: huaweicloudsdkswr/v2/model/create_repo_request.py <==
# coding: utf-8

import pprint
import re

import six





class CreateRepoRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'namespace': 'str',
        'body': 'CreateRepoRequestBody'
    }

    attribute_map = {
        'namespace': 'namespace',
        'body': 'body'
    }

    def __init__(self, namespace=None, body=None):
        """CreateRepoRequest - a model defined in huaweicloud sdk"""
        
        

        self._namespace = None
        self._body = None
        self.discriminator = None

        self.namespace = namespace
        if body is not None:
            self.body = body

    @property
    def namespace(self):
        """Gets the namespace of this CreateRepoRequest.

        组织名称。小写字母开头，后面跟小写字母、数字、小数点、下划线或中划线（其中下划线最多允许连续两个，小数点、下划线、中划线不能直接相连），小写字母或数字结尾，1-64个字符。

        :return: The namespace of this CreateRepoRequest.
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this CreateRepoRequest.

        组织名称。小写字母开头，后面跟小写字母、数字、小数点、下划线或中划线（其中下划线最多允许连续两个，小数点、下划线、中划线不能直接相连），小写字母或数字结尾，1-64个字符。

        :param namespace: The namespace of this CreateRepoRequest.
        :type: str
        """
        self._namespace = namespace

    @property
    def body(self):
        """Gets the body of this CreateRepoRequest.


        :return: The body of this CreateRepoRequest.
        :rtype: CreateRepoRequestBody
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this CreateRepoRequest.


        :param body: The body of this CreateRepoRequest.
        :type: CreateRepoRequestBody
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateRepoRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkswr-3.0.51-py2.py3-none-any.whl: huaweicloudsdkswr/v2/model/create_repo_request.py <==
# coding: utf-8

import re
import six





class CreateRepoRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'namespace': 'str',
        'body': 'CreateRepoRequestBody'
    }

    attribute_map = {
        'namespace': 'namespace',
        'body': 'body'
    }

    def __init__(self, namespace=None, body=None):
        """CreateRepoRequest - a model defined in huaweicloud sdk"""
        
        

        self._namespace = None
        self._body = None
        self.discriminator = None

        self.namespace = namespace
        if body is not None:
            self.body = body

    @property
    def namespace(self):
        """Gets the namespace of this CreateRepoRequest.

        组织名称。小写字母开头，后面跟小写字母、数字、小数点、下划线或中划线（其中下划线最多允许连续两个，小数点、下划线、中划线不能直接相连），小写字母或数字结尾，1-64个字符。

        :return: The namespace of this CreateRepoRequest.
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this CreateRepoRequest.

        组织名称。小写字母开头，后面跟小写字母、数字、小数点、下划线或中划线（其中下划线最多允许连续两个，小数点、下划线、中划线不能直接相连），小写字母或数字结尾，1-64个字符。

        :param namespace: The namespace of this CreateRepoRequest.
        :type: str
        """
        self._namespace = namespace

    @property
    def body(self):
        """Gets the body of this CreateRepoRequest.


        :return: The body of this CreateRepoRequest.
        :rtype: CreateRepoRequestBody
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this CreateRepoRequest.


        :param body: The body of this CreateRepoRequest.
        :type: CreateRepoRequestBody
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateRepoRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
